@@ -1,11 +1,12 @@
 # import from modules
 from .concatenate import Concatenate
-from .conv2d import Conv2d
+from .conv import Conv1d, Conv2d, Conv3d, Conv
 from .linear import Linear
 from .log import Log
 from .patching import Patching, PatchEmbedding2d
 from .positional_embedding import PositionalEmbedding
 from .reshape import Reshape
+from .stack import Stack
 # import from other libraries
 from torch.nn import MultiheadAttention as _Attention
 
@@ -14,11 +15,15 @@ Attention = _Attention
 __all__ = [
     "Attention",
     "Concatenate",
+    "Conv1d",
     "Conv2d",
+    "Conv3d",
+    "Conv",
     "Linear",
     "Log",
     "Patching",
     "PatchEmbedding2d",
     "PositionalEmbedding",
     "Reshape",
+    "Stack",
 ]
