@@ -1,9 +1,11 @@
 from .imshow import imshow
 from .log_graph import log_graph
 from . import watcher
+from . import tensorboard
 
 __all__ = [
     "imshow",
     "log_graph",
-    "watcher"
+    "watcher",
+    "tensorboard"
 ]
