@@ -1,3 +1,4 @@
+import os.path
 import unittest
 
 import tensorneko
@@ -7,6 +8,8 @@ class TestLibraryInfo(unittest.TestCase):
 
     def test_version(self):
         version = tensorneko.io.read.text.of("version.txt")
+
+        tensorneko.io.write.text.to(os.path.join("src", "tensorneko", "version.txt"), version)
         self.assertEqual(tensorneko.__version__, version)
 
 
